pub enum RangeError {
Malformed,
MultiRangeUnsupported,
Unsatisfiable,
}Expand description
Why an HTTP Range header could not be resolved to a concrete ByteRange.
Variants
Malformed
The header was not a well-formed single bytes= range.
MultiRangeUnsupported
The header requested more than one range; unsupported.
Unsatisfiable
The requested range starts at or beyond the content length.